@@ -1,25 +1,8 @@
 //
 // Copyright 2023 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_IMAGING_HD_FLATTENED_DATA_SOURCE_PROVIDER_H
 #define PXR_IMAGING_HD_FLATTENED_DATA_SOURCE_PROVIDER_H
@@ -28,6 +11,7 @@
 
 #include "pxr/imaging/hd/dataSource.h"
 #include "pxr/imaging/hd/retainedDataSource.h"
+#include "pxr/imaging/hd/sceneIndex.h"
 #include "pxr/usd/sdf/path.h"
 
 PXR_NAMESPACE_OPEN_SCOPE
@@ -52,11 +36,11 @@ public:
             const HdSceneIndexBase &flatteningSceneIndex,
             const SdfPath &primPath,
             const TfToken &name,
-            const HdContainerDataSourceHandle &inputPrimDataSource)
+            const HdSceneIndexPrim &inputPrim)
           : _flatteningSceneIndex(flatteningSceneIndex)
           , _primPath(primPath)
           , _name(name)
-          , _inputPrimDataSource(inputPrimDataSource)
+          , _inputPrim(inputPrim)
         {
         }
 
@@ -68,14 +52,22 @@ public:
         // container data source of the parent prim.
         HD_API
         HdContainerDataSourceHandle GetFlattenedDataSourceFromParentPrim() const;
+        // Returns the type of the prim from the input scene index.
+        HD_API
+        const TfToken &GetInputPrimType() const {
+            return _inputPrim.primType;
+        }
 
     private:
         const HdSceneIndexBase &_flatteningSceneIndex;
         const SdfPath &_primPath;
         const TfToken &_name;
-        const HdContainerDataSourceHandle &_inputPrimDataSource;
+        const HdSceneIndexPrim _inputPrim;
     };
 
+    HD_API
+    virtual ~HdFlattenedDataSourceProvider();
+
     /// Returns flattened data source.
     virtual HdContainerDataSourceHandle GetFlattenedDataSource(
         const Context &ctx) const = 0;
